@@ -158,6 +158,43 @@ def cross_val(  algorithms : list,
                 verbose : int or bool = 0, 
                 early_stopping_rounds : int = 0, 
                 ) -> float:
+                
+    ''' 
+    Cross Validation method for list of algorithms.
+    
+    Use case:
+    score = Snaplib().cross_val(algorithms, 
+                                k_fold_dict, 
+                                metric, 
+                                task, 
+                                cv, 
+                                verbose=0, 
+                                early_stopping_rounds=0)
+    
+    algorithms is a list of algorithms like algs = [
+                                                    [LGBMClassifier, dict(params)],
+                                                    [XGBClassifier, dict(params)], 
+                                                    [CatBoostClassifier, dict(params)],
+                                                    ]
+    k_fold_dict is a dictionary with the structure:
+    
+    K_FOLD = 3
+    k_fold_dict = { 
+                    'train_X' : [df_0, df_1, df_2],
+                    'test_X'  : [df_0, df_1, df_2],
+                    'train_y' : [seri_0, seri_1, seri_2],
+                    'test_y'  : [seri_0, seri_1, seri_2],
+                    }
+
+    Get k_fold_dict:
+    k_fold_dict = Snaplib().k_folds_split(df, target_name_str, K_FOLD)
+            
+    metric is a metric like f1_score or mean_absolute_error : Callable.
+    task='clsf' or 'regr', classification or regression.
+    cv is num K_FOLD integer 
+    verbose = 0 mute, 1 verbose.
+    early_stopping_rounds default 0 or positive int.
+    '''
 
     if type(algorithms) != list:
         raise TypeError('The algorithms must be of list type.')
