@@ -23,7 +23,7 @@ from . import counter
 def recover_data(df_0 : pd.DataFrame, 
                 device : str = 'cpu',
                 verbose : int or bool = True,
-                discrete_columns : list[str] or str = 'auto', 
+                discrete_columns : list or str = 'auto', 
                 ) -> pd.DataFrame:
     ''' 
     Imputing of missing values (np.nan) in tabular data, not TimeSeries.
